biom.table.Table.descriptive_equality — biom-format.org

# biom-format.org

## biom.table.Table.descriptive_equality

« biom.table.Table.delimited_self :: Contents :: biom.table.Table.exists »

# biom.table.Table.descriptive_equality

`Table.` `descriptive_equality`(other)

  For use in testing, describe how the tables are not equal

« biom.table.Table.delimited_self :: Contents :: biom.table.Table.exists »

© Copyright 2011-2013, The BIOM Format Development Team. Last updated on Nov 19, 2014. Created using Sphinx 1.2.3.